OiRA

Help

1. Voorbereiding
3. Inventarisatie + Evaluatie
4. Plan van aanpak
5. Rapport
6. Status 0%

# Maak de RI&E op maat voor uw organisatie

Lees de onderstaande vragen en zet een vinkje als deze van toepassing is voor uw organisatie.
Om de risico inventarisatie af te stemmen op uw organisatie, wordt u hieronder gevraagd om:

- aan te vinken of de situatie op u van toepassing is. Indien het niet van toepassing is, laat u het vakje open en krijgt u geen vragen in de RI&E over dit onderwerp.
- meerdere bedrijfseenheden, filialen, winkels in te vullen als u die wilt meenemen in deze inventarisatie. De gerelateerde risico's zullen worden herhaald voor elke naam die u hebt ingevoerd.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More